@@ -12,7 +12,7 @@
  * software for any purpose.  It is provided "as is" without express or
  * implied warranty.
  *-----------------------------------------------------------------------------
- * $Id: tclXprofile.c,v 1.2 2002/09/26 00:19:18 hobbs Exp $
+ * $Id: tclXprofile.c,v 1.4 2009/10/13 19:28:23 kot Exp $
  *-----------------------------------------------------------------------------
  */
 
@@ -123,7 +123,7 @@ static int
 ProfStrCommandEval _ANSI_ARGS_((ClientData    clientData,
                                 Tcl_Interp   *interp,
                                 int           argc,
-                                char        **argv));
+                                CONST84 char **argv));
 
 static int
 ProfObjCommandEval _ANSI_ARGS_((ClientData    clientData,
@@ -524,7 +524,7 @@ ProfStrCommandEval (clientData, interp, argc, argv)
     ClientData    clientData;
     Tcl_Interp   *interp;
     int           argc;
-    char        **argv;
+    CONST84 char **argv;
 {
     profInfo_t *infoPtr = (profInfo_t *) clientData;
     Command *currentCmdPtr;
@@ -673,7 +673,7 @@ InitializeProcStack (infoPtr, framePtr)
     profInfo_t *infoPtr;
     CallFrame  *framePtr;
 {
-    if (framePtr == NULL)
+    if (framePtr == NULL || framePtr->objv == NULL)
         return;
     InitializeProcStack (infoPtr, framePtr->callerPtr);
     
